@@ -112,7 +112,7 @@ def sumOfDigits(number):
 #Перевод числа из десятичной системы счисления в любую с помощью словаря
 #Автор: Алексей Большаков
 def decToBase(a, base):
-    dict_ = '0123456789abcdefghi'
+    dict_ = '0123456789abcdefghijklmnop'
     s = ''
     while a != 0:
         s = str(dict_[a % base]) + s
@@ -158,7 +158,7 @@ def turtle_6(code, gridSizeX = 16, gridSizeY = 16, gridScale = 20, gridDotSize =
             continue
 
 
-    turtleFuncs = {"Вперёд": t.forward, "Направо": t.right, "Налево:": t.left, "Назад": t.back, "Поднять": t.penup, "Опустить": t.pendown}
+    turtleFuncs = {"Вперёд": t.forward, "Направо": t.right, "Налево": t.left, "Назад": t.back, "Поднять": t.penup, "Опустить": t.pendown}
 
     for x in range(gridSizeX):
         for y in range(gridSizeY):
